==> magic3_1.8.0_b15_src.tar.gz: magic3/scripts/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/lang/en.js <==
/*
 * FCKeditor - The text editor for internet
 * Copyright (C) 2003-2006 Frederico Caldeira Knabben
 * 
 * Licensed under the terms of the GNU Lesser General Public License:
 * 		http://www.opensource.org/licenses/lgpl-license.php
 * 
 * For further information visit:
 * 		http://www.fckeditor.net/
 * 
 * "Support Open Source software. What about a donation today?"
 * 
 * File Name: en.js
 * 	SimpleFileBrowser English language file.
 * 
 * File Authors:
 * 		Akira Taniguchi (akira@behappy.2-d.jp)
 */
FCKLang.Browser						= 'Resources Browser' ;

FCKLang.BrowserResourceType			= 'Resource Type' ;
FCKLang.BrowserResourceTypeFile		= 'File' ;
FCKLang.BrowserResourceTypeImage	= 'Image' ;
FCKLang.BrowserResourceTypeFlash	= 'Flash' ;
FCKLang.BrowserResourceTypeMedia	= 'Media' ;

FCKLang.BrowserNameExists			= 'The name already exists' ;
FCKLang.BrowserNoPermission			= 'You have no permissions' ;
FCKLang.BrowserDisableName			= 'Invalid name' ;
FCKLang.BrowserDisableChars			= 'Invalid charactor\n\\/:"*?<>|' ;

FCKLang.BrowserFileSize				= 'Size' ;
FCKLang.BrowserFileDelete			= 'Delete File' ;
FCKLang.BrowserFileDeleteConfirm	= 'Are you sure you wish to delete "%1"' ;
FCKLang.BrowserFileDeleteError		= 'Failed to delete file' ;

FCKLang.BrowserFileRename			= 'Rename File' ;
FCKLang.BrowserFileRenameMessage	= 'Please enter the new file name for "%1"' ;
FCKLang.BrowserFileRenameExtChange	= 'File extension is not changeable' ;
FCKLang.BrowserFileRenameError		= 'Failed to rename file' ;

FCKLang.BrowserFolderDelete			= 'Delete Folder' ;
FCKLang.BrowserFolderDeleteConfirm	= 'Are you sure you wish to delete "%1" and all files in it?' ;
FCKLang.BrowserFolderDeleteError	= 'Failed to delete folder' ;

FCKLang.BrowserFolderRename			= 'Rename Folder' ;
FCKLang.BrowserFolderRenameMessage	= 'Please enter the new folder name for "%1"' ;
FCKLang.BrowserFolderRenameError	= 'Failed to rename folder' ;

FCKLang.BrowserNewFolderMessage		= 'Create New Folder' ;
FCKLang.BrowserNewFolderNameMessage	= 'Type the name of the new folder' ;
FCKLang.BrowserNewFolderError		= 'Failed to create folder' ;

FCKLang.BrowserUpload				= 'Upload' ;
FCKLang.BrowserUploadMessage		= 'Upload a new file in this folder' ;
FCKLang.BrowserUploadMessageWait	= 'Upload a new file in this folder (Upload in progress, please wait...)' ;
FCKLang.BrowserUploadNoFile			= 'Please select a file from your computer' ;
FCKLang.BrowserUploadAvailable		= 'A file with the same name is already available. The uploaded file has been renamed to "%1"' ;
FCKLang.BrowserUploadNoParam		= 'Invalid parametor' ;
FCKLang.BrowserUploadTooBig			= 'This file exceeds the maximum upload size %1KB' ;
FCKLang.BrowserUploadExtNothing		= 'Unable to determine file type of file' ;
FCKLang.BrowserUploadExtDisable		= 'Disallowed file type' ;
FCKLang.BrowserUploadSizeError		= 'Unable to determine the size of a folder\n\n"%1"' ;
FCKLang.BrowserUploadQuotaGlobal	= 'You are over the global disk quota %1MB' ;
FCKLang.BrowserUploadQuotaType		= 'You are over the disk quota for this resource type %1MB' ;
FCKLang.BrowserUploadAvailableMany	= 'There are too many same file names' ;
FCKLang.BrowserUploadNotUploaded	= 'Invalid upload process' ;
FCKLang.BrowserUploadInvalid		= 'Failed to upload file' ;
FCKLang.BrowserUploadNotMoved		= 'Failed to upload a new file in this folder. Check the folder permission\n\n"%1"';

==> magic3_1.11.8_src.tar.gz: magic3/scripts/fckeditor2.6/editor/plugins/FileBrowser_Thumbnail/lang/en.js <==
/*
 * FCKeditor - The text editor for internet
 * Copyright (C) 2003-2006 Frederico Caldeira Knabben
 * 
 * Licensed under the terms of the GNU Lesser General Public License:
 * 		http://www.opensource.org/licenses/lgpl-license.php
 * 
 * For further information visit:
 * 		http://www.fckeditor.net/
 * 
 * "Support Open Source software. What about a donation today?"
 * 
 * File Name: en.js
 * 	SimpleFileBrowser English language file.
 * 
 * File Authors:
 * 		Akira Taniguchi (akira@behappy.2-d.jp)
 */
FCKLang.Browser						= 'Resources Browser' ;

FCKLang.BrowserResourceType			= 'Resource Type' ;
FCKLang.BrowserResourceTypeFile		= 'File' ;
FCKLang.BrowserResourceTypeImage	= 'Image' ;
FCKLang.BrowserResourceTypeFlash	= 'Flash' ;
FCKLang.BrowserResourceTypeMedia	= 'Media' ;

FCKLang.BrowserNameExists			= 'The name already exists' ;
FCKLang.BrowserNoPermission			= 'You have no permissions' ;
FCKLang.BrowserDisableName			= 'Invalid name' ;
FCKLang.BrowserDisableChars			= 'Invalid charactor\n\\/:"*?<>|' ;

FCKLang.BrowserFileSize				= 'Size' ;
FCKLang.BrowserFileDelete			= 'Delete File' ;
FCKLang.BrowserFileDeleteConfirm	= 'Are you sure you wish to delete "%1"' ;
FCKLang.BrowserFileDeleteError		= 'Failed to delete file' ;

FCKLang.BrowserFileRename			= 'Rename File' ;
FCKLang.BrowserFileRenameMessage	= 'Please enter the new file name for "%1"' ;
FCKLang.BrowserFileRenameExtChange	= 'File extension is not changeable' ;
FCKLang.BrowserFileRenameError		= 'Failed to rename file' ;

FCKLang.BrowserFolderDelete			= 'Delete Folder' ;
FCKLang.BrowserFolderDeleteConfirm	= 'Are you sure you wish to delete "%1" and all files in it?' ;
FCKLang.BrowserFolderDeleteError	= 'Failed to delete folder' ;

FCKLang.BrowserFolderRename			= 'Rename Folder' ;
FCKLang.BrowserFolderRenameMessage	= 'Please enter the new folder name for "%1"' ;
FCKLang.BrowserFolderRenameError	= 'Failed to rename folder' ;

FCKLang.BrowserNewFolderMessage		= 'Create New Folder' ;
FCKLang.BrowserNewFolderNameMessage	= 'Type the name of the new folder' ;
FCKLang.BrowserNewFolderError		= 'Failed to create folder' ;

FCKLang.BrowserUpload				= 'Upload' ;
FCKLang.BrowserUploadMessage		= 'Upload a new file in this folder' ;
FCKLang.BrowserUploadMessageWait	= 'Upload a new file in this folder (Upload in progress, please wait...)' ;
FCKLang.BrowserUploadNoFile			= 'Please select a file from your computer' ;
FCKLang.BrowserUploadAvailable		= 'A file with the same name is already available. The uploaded file has been renamed to "%1"' ;
FCKLang.BrowserUploadNoParam		= 'Invalid parametor' ;
FCKLang.BrowserUploadTooBig			= 'This file exceeds the maximum upload size %1KB' ;
FCKLang.BrowserUploadExtNothing		= 'Unable to determine file type of file' ;
FCKLang.BrowserUploadExtDisable		= 'Disallowed file type in this folder' ;
FCKLang.BrowserUploadSizeError		= 'Unable to determine the size of a folder\n\n"%1"' ;
FCKLang.BrowserUploadQuotaGlobal	= 'You are over the global disk quota %1MB' ;
FCKLang.BrowserUploadQuotaType		= 'You are over the disk quota for this resource type %1MB' ;
FCKLang.BrowserUploadAvailableMany	= 'There are too many same file names' ;
FCKLang.BrowserUploadNotUploaded	= 'Invalid upload process' ;
FCKLang.BrowserUploadInvalid		= 'Failed to upload file' ;
FCKLang.BrowserUploadNotMoved		= 'Failed to upload a new file in this folder. Check the folder permission\n\n"%1"';
